@@ -1,6 +1,4 @@
-from pathlib import Path
-
-from . import endpoints, file_contents, gateways, helpers, jobs
+from . import endpoints, gateways, helpers, jobs
 from .configs import Config
 
 
@@ -20,10 +18,16 @@ def main(args) -> int:
 
     if args.which == 'init':
         config.base_dir = args.base_dir or helpers.ask_for('Base directory', '.')
-        config.api_title = args.api_title or helpers.ask_for('API title', 'My API')
-        config.api_description = args.api_description or helpers.ask_for('API description', 'My API description')
-        config.gcp_project = args.gcp_project or helpers.ask_for('GCP project')
-        config.gcp_region = args.gcp_region or helpers.ask_for('GCP region', 'europe-west1')
+
+        # Cloud
+        config.cloud = args.cloud or helpers.ask_for('Cloud', 'gcp')
+        config.project = args.project or helpers.ask_for('Cloud project')
+        config.region = args.region or helpers.ask_for('Cloud region', 'europe-west1')
+
+        # Endpoints
+        config.endpoint_api_title = args.api_title or helpers.ask_for('Endpoint API title', 'My API')
+        config.endpoint_api_description = args.api_description or helpers.ask_for('Endpoint API description', 'My API description')
+
         config.save()
         print(helpers.bcolors.OKGREEN + 'Init config success' + helpers.bcolors.ENDC)
         return 0
