@@ -24,7 +24,7 @@ class Runtime:
 
     @property
     def command(self) -> str:
-        return f'gcloud functions deploy --project="{self.config.gcp_project}" {self.operation_id} {self.trigger}--runtime {self.runtime} --entry-point="{self.entry_point}" --memory={self.memory} --region="{self.config.gcp_region}"'
+        return f'gcloud functions deploy --project="{self.config.project}" {self.operation_id} {self.trigger} --runtime {self.runtime} --entry-point="{self.entry_point}" --memory={self.memory} --region="{self.config.region}"'
 
 
 class Endpoint:
@@ -90,10 +90,10 @@ def init_file_structure(config: Config):
     if not Path(base_dir, 'api.yaml').exists():
         with open(f"{base_dir}/api.yaml", "w") as file:
             file.write(file_contents.api(
-                title=config.api_title,
-                description=config.api_description,
-                project=config.gcp_project,
-                region=config.gcp_region,
+                title=config.endpoint_api_title,
+                description=config.endpoint_api_description,
+                project=config.project,
+                region=config.region,
             ))
     if not Path(base_dir, 'requirements.txt').exists():
         with open(f"{base_dir}/requirements.txt", "w") as file:
