@@ -99,15 +99,22 @@ class StepCommand(Step):
         self.command = command
         self.work_dir = kwargs.get('work_dir')
         self.can_fail = kwargs.get('can_fail', False)
+        self.retry = kwargs.get('retry', 0)
 
     def run(self, config: Config, simulate: bool = False):
         print('+ Run command:')
         print(" ".join(self.command))
         if not simulate:
-            p = subprocess.run(self.command, stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=self.work_dir)
-            if not self.can_fail:
-                if p.returncode != 0:
-                    raise exceptions.CommandError('command not success')
+            while True:
+                count = 0
+                p = subprocess.run(self.command, stdout=subprocess.PIPE, cwd=self.work_dir)
+                if not self.can_fail:
+                    if p.returncode != 0:
+                        if count < self.retry:
+                            count += 1
+                            continue
+                        raise exceptions.CommandError('command not success')
+                break
 
 
 class Manager:
